==> spip_4.0.4.orig.tar.xz: plugins-dist/dump/lang/dump_ro.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/dump?lang_cible=ro
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_restaurer_base' => 'Restauraţi baza de date',

	// I
	'info_restauration_sauvegarde' => 'Restaurarea salvării @archive@',
	'info_sauvegarde' => 'Salvare',
	'info_sauvegarde_reussi_02' => 'Baza de date a fost salvată în @archive@. Puteţi',
	'info_sauvegarde_reussi_03' => ' să vă întoarceţi la gestionarea',
	'info_sauvegarde_reussi_04' => ' site-ului dumneavoastră.',

	// T
	'texte_admin_tech_01' => 'Această opţiune vă permite să salvaţi conţinutul bazei de date intr-un fişier care va fi pus în directorul @dossier@. Nu uitaţi, de asemenea, să recuperaţi directorul @img@ în integralitatea lui - acesta conţine imaginile şi documentele folosite în articole şi rubrici.',
	'texte_admin_tech_02' => 'Atenţie: această salvare nu va putea fi restaurată DECÂT pe un site instalat folosind aceeaşi versiune de SPIP. Mai ales, nu trebuie sa « goliţi baza de date » sperând că, după o aducere la zi... veţi putea reinstala ceea ce aţi salvat ... Consultaţi <a href="@spipnet@">documentaţia SPIP</a>.', # MODIF
	'texte_restaurer_base' => 'Restauraţi conţinutul bazei de date plecând de la o salvare',
	'texte_restaurer_sauvegarde' => 'Această opţiune vă permite să restauraţi o copie de siguranţă a bazei de date pe care aţi făcut-o anterior. Pentru aceasta vă rugăm să vă asiguraţi ca fişierul de copie de siguranţă
  se află în directorul @dossier@.
  Fiţi prudent cu această funcţionalitate : <b>modificările, pierderile eventuale, sunt
  ireversibile.</b>', # MODIF
	'texte_sauvegarde' => 'Salvaţi conţinutul bazei de date',
	'texte_sauvegarde_base' => 'Salvaţi baza de date'
);

==> spip_4.4.7+dfsg.orig.tar.xz: plugins-dist/dump/lang/dump_ro.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/dump?lang_cible=ro
// ** ne pas modifier le fichier **

return [

	// B
	'bouton_restaurer_base' => 'Restauraţi baza de date',

	// I
	'info_restauration_sauvegarde' => 'Restaurarea salvării @archive@',
	'info_sauvegarde' => 'Salvare',
	'info_sauvegarde_reussi_02' => 'Baza de date a fost salvată în @archive@. Puteţi',
	'info_sauvegarde_reussi_03' => ' să vă întoarceţi la gestionarea',
	'info_sauvegarde_reussi_04' => ' site-ului dumneavoastră.',

	// T
	'texte_admin_tech_01' => 'Această opţiune vă permite să salvaţi conţinutul bazei de date intr-un fişier care va fi pus în directorul @dossier@. Nu uitaţi, de asemenea, să recuperaţi directorul @img@ în integralitatea lui - acesta conţine imaginile şi documentele folosite în articole şi rubrici.',
	'texte_admin_tech_02' => 'Atenţie: această salvare nu va putea fi restaurată DECÂT pe un site instalat folosind aceeaşi versiune de SPIP. Mai ales, nu trebuie sa « goliţi baza de date » sperând că, după o aducere la zi... veţi putea reinstala ceea ce aţi salvat ... Consultaţi <a href="@spipnet@">documentaţia SPIP</a>.', # MODIF
	'texte_restaurer_base' => 'Restauraţi conţinutul bazei de date plecând de la o salvare',
	'texte_restaurer_sauvegarde' => 'Această opţiune vă permite să restauraţi o copie de siguranţă a bazei de date pe care aţi făcut-o anterior. Pentru aceasta vă rugăm să vă asiguraţi ca fişierul de copie de siguranţă
  se află în directorul @dossier@.
  Fiţi prudent cu această funcţionalitate : <b>modificările, pierderile eventuale, sunt
  ireversibile.</b>', # MODIF
	'texte_sauvegarde' => 'Salvaţi conţinutul bazei de date',
	'texte_sauvegarde_base' => 'Salvaţi baza de date',
];
